@@ -31,22 +31,22 @@ MLControl_depwarn <- function(summary = NULL, cutoff = NULL,
                               cutoff_index = NULL, na.rm = NULL, ...) {
   if (!is.null(summary)) {
     depwarn("'summary' argument to MLControl is deprecated",
-            "apply the modelmetrics function to Resamples output directly")
+            "apply the 'performance' function to Resamples output directly")
   }
   
   if (!is.null(cutoff)) {
     depwarn("'cutoff' argument to MLContorl is deprecated",
-            "specify in calls to modelmetrics instead")
+            "specify in calls to 'performance' instead")
   }
   
   if (!is.null(cutoff_index)) {
     depwarn("'cutoff_index' argument to MLControl is deprecated",
-            "specify in calls to modelmetrics instead")
+            "specify in calls to 'performance' instead")
   }
   
   if (!is.null(na.rm)) {
     depwarn("'na.rm' argument to MLControl is deprecated",
-            "specify in calls to modelmetrics instead")
+            "specify in calls to 'performance' instead")
   }
 }
 
@@ -70,11 +70,11 @@ setClass("MLControl",
 #' BootControl(samples = 100)
 #' 
 BootControl <- function(samples = 25, ...) {
-  new("BootMLControl", MLControl(...), samples = samples)
+  new("MLControlBoot", MLControl(...), samples = samples)
 }
 
 
-setClass("BootMLControl",
+setClass("MLControlBoot",
   slots = c(samples = "numeric"),
   contains = "MLControl"
 )
@@ -96,11 +96,11 @@ setClass("BootMLControl",
 #' CVControl(folds = 10, repeats = 5)
 #' 
 CVControl <- function(folds = 10, repeats = 1, ...) {
-  new("CVMLControl", MLControl(...), folds = folds, repeats = repeats)
+  new("MLControlCV", MLControl(...), folds = folds, repeats = repeats)
 }
 
 
-setClass("CVMLControl",
+setClass("MLControlCV",
   slots = c(folds = "numeric", repeats = "numeric"),
   contains = "MLControl"
 )
@@ -118,11 +118,11 @@ setClass("CVMLControl",
 #' OOBControl(samples = 100)
 #' 
 OOBControl <- function(samples = 25, ...) {
-  new("OOBMLControl", MLControl(...), samples = samples)
+  new("MLControlOOB", MLControl(...), samples = samples)
 }
 
 
-setClass("OOBMLControl",
+setClass("MLControlOOB",
   slots = c(samples = "numeric"),
   contains = "MLControl"
 )
@@ -142,11 +142,11 @@ setClass("OOBMLControl",
 #' SplitControl(prop = 2/3)
 #' 
 SplitControl <- function(prop = 2/3, ...) {
-  new("SplitMLControl", MLControl(...), prop = prop)
+  new("MLControlSplit", MLControl(...), prop = prop)
 }
 
 
-setClass("SplitMLControl",
+setClass("MLControlSplit",
   slots = c(prop = "numeric"),
   contains = "MLControl"
 )
@@ -163,11 +163,11 @@ setClass("SplitMLControl",
 #' TrainControl()
 #' 
 TrainControl <- function(...) {
-  new("TrainMLControl", MLControl(...))
+  new("MLControlTrain", MLControl(...))
 }
 
 
-setClass("TrainMLControl",
+setClass("MLControlTrain",
   contains = "MLControl"
 )
 
@@ -181,20 +181,123 @@ MLFitBits <- setClass("MLFitBits",
 )
 
 
+#' MLMetric Class Constructor
+#' 
+#' Create a performance metric for use with the \pkg{MachineShop} package.
+#' 
+#' @rdname MLMetric
+#' 
+#' @param object function to compute the metric.  Must be defined to accept
+#' \code{observed} and \code{predicted} as the first two arguments and with an
+#' ellipsis (\code{...}) to accommodate others.
+#' @param name character string name for the instantiated \code{MLMetric}
+#' object; same as the metric function name.
+#' @param label descriptive label for the metric.
+#' @param maximize logical indicating whether to maximize the metric for better
+#' performance.
+#' 
+#' @return \code{MLMetric} class object.
+#' 
+#' @seealso \code{\link{metrics}}, \code{\link{metricinfo}}
+#' 
+MLMetric <- function(object, name = "MLMetric", label = name, maximize = TRUE) {
+  new("MLMetric", object, name = name, label = label, maximize = maximize)
+}
+
+
+#' @rdname MLMetric
+#' 
+#' @param value list of arguments to pass to the \code{MLMetric} constructor.
+#' 
+#' @examples
+#' f2_score <- function(observed, predicted, ...) {
+#'   f_score(observed, predicted, beta = 2, ...)
+#' }
+#' 
+#' MLMetric(f2_score) <- list(name = "f2_score",
+#'                            label = "F Score (beta = 2)",
+#'                            maximize = TRUE)
+#' 
+"MLMetric<-" <- function(object, value) {
+  do.call(MLMetric, c(object, value))
+}
+
+
+setClass("MLMetric",
+  slots = c(name = "character", label = "character", maximize = "logical"),
+  contains = "function"
+)
+
+
 #' MLModel Class Constructor
 #' 
-#' @param name character string name for the instantiated \code{MLModel} object.
-#' @param packages character vector of packages required by the object.
-#' @param types character vector of response variable types on which the model
-#' can be fit.
-#' @param params list of user-specified model parameters.
-#' @param nvars function to return the number of predictor variables for a
-#' given model frame.
-#' @param fit model fitting function.
-#' @param predict model prediction function.
-#' @param varimp variable importance function.
+#' Create a model for use with the \pkg{MachineShop} package.
 #' 
-MLModel <- function(name = "MLModel", packages = character(0),
+#' @param name character string name for the instantiated \code{MLModel} object;
+#' same name as the object to which the model is assigned.
+#' @param label descriptive label for the model.
+#' @param packages character vector of packages whose namespaces are required by
+#' the model.
+#' @param types character vector of response variable types to which the model
+#' can be fit.  Supported types are \code{"binary"}, \code{"factor"},
+#' \code{"matrix"}, \code{"numeric"}, \code{"ordered"}, and \code{"Surv"}.
+#' @param params list of user-specified model parameters to be passed to the
+#' \code{fit} function.
+#' @param nvars function to determine the number of variables included in the
+#' model from the \code{data} frame used by \code{fit}.
+#' @param fit model fitting function whose arguments are a \code{formula}, a
+#' \code{data} frame, case \code{weights}, and an ellipsis (\code{...}).
+#' @param predict model prediction function whose arguments are the
+#' \code{object} returned by \code{fit}, a \code{newdata} frame of predictor
+#' variables, optional vector of \code{times} at which to predict survival,
+#' and an ellipsis.
+#' @param varimp variable importance function whose arguments are the
+#' \code{object} returned by \code{fit}, optional arguments passed from calls
+#' to \code{\link{varimp}}, and an ellipsis.
+#' 
+#' @details
+#' Values returned by the \code{predict} functions should be formatted according
+#' to the response variable types below.
+#' \describe{
+#' \item{factor}{a vector or column matrix of probabilities for the second level
+#' of binary factors or a matrix whose columns contain the probabilities for
+#' factors with more than two levels.}
+#' \item{matrix}{a matrix of predicted responses.}
+#' \item{numeric}{a vector or column matrix of predicted responses.}
+#' \item{Surv}{a matrix whose columns contain survival probabilities at
+#' \code{times} if supplied or a vector of survival predictions otherwise.}
+#' }
+#' 
+#' The \code{varimp} function should return a vector of importance values named
+#' after the predictor variables or a matrix or data frame whose rows are named
+#' after the predictors.
+#' 
+#' @return \code{MLModel} class object.
+#' 
+#' @seealso \code{\link{modelinfo}}, \code{\link{fit}}, \code{\link{resample}},
+#' \code{\link{tune}}
+#' 
+#' @examples
+#' ## Logistic regression model
+#' LogisticModel <- MLModel(
+#'   name = "LogisticModel",
+#'   types = "binary",
+#'   fit = function(formula, data, weights, ...) {
+#'     glm(formula, data = data, weights = weights, family = binomial, ...)
+#'   },
+#'   predict = function(object, newdata, ...) {
+#'     predict(object, newdata = newdata, type = "response")
+#'   },
+#'   varimp = function(object, ...) {
+#'     pchisq(coef(object)^2 / diag(vcov(object)), 1)
+#'   }
+#' )
+#' 
+#' library(MASS)
+#' res <- resample(type ~ ., data = Pima.tr, model = LogisticModel)
+#' summary(res)
+#' 
+MLModel <- function(name = "MLModel", label = name, packages = character(0),
                     types = character(0), params = list(),
                     nvars = function(data) NULL,
                     fit = function(formula, data, weights, ...)
@@ -208,6 +311,7 @@ MLModel <- function(name = "MLModel", packages = character(0),
   
   new("MLModel",
       name = name,
+      label = label,
       packages = packages,
       types = types,
       params = params,
@@ -221,6 +325,7 @@ MLModel <- function(name = "MLModel", packages = character(0),
 
 setClass("MLModel",
   slots = c(name = "character",
+            label = "character",
             packages = "character",
             types = "character",
             params = "list",
@@ -248,6 +353,145 @@ setClass("SVMTanhModelFit", contain = c("MLModelFit", "ksvm"))
 setClass("CForestModelFit", contains = c("MLModelFit", "RandomForest"))
 
 
+#' @name calibration
+#' @rdname calibration
+#' 
+#' @param ... named or unnamed \code{calibration} output to combine together
+#' with the \code{Calibration} constructor.
+#' 
+Calibration <- function(...) {
+  args <- list(...)
+  
+  if (!all(sapply(args, is.data.frame))) {
+    stop("values to combine must inherit from data.frame")
+  }
+  
+  var_names <- c("Response", "Predicted", "Observed")
+  for (x in args) {
+    is_missing <- !(var_names %in% names(x))
+    if (any(is_missing)) {
+      stop("missing calibration variables: ", toString(var_names[is_missing]))
+    }
+  }
+
+  args <- make_unique_levels(args, which = "Model")
+  new("Calibration", do.call(append, args))
+}
+
+
+setClass("Calibration",
+  contains = "data.frame"
+)
+
+
+#' @name confusion
+#' @rdname confusion
+#' 
+#' @param ... named or unnamed \code{confusion} output to combine together with
+#' the \code{Confusion} constructor.
+#' 
+Confusion <- function(...) {
+  args <- list(...)
+  
+  conf_list <- list()
+  for (i in seq(args)) {
+    x <- args[[i]]
+    if (is(x, "ConfusionMatrix")) {
+      x <- list("Model" = x)
+    } else if (!is(x, "Confusion")) {
+      stop("values to combine must be Confusion or ConfusionMatrix objects")
+    }
+    arg_name <- names(args)[i]
+    if (!is.null(arg_name) && nzchar(arg_name)) {
+      names(x) <- rep(arg_name, length(x))
+    }
+    conf_list <- c(conf_list, x)
+  }
+  names(conf_list) <- make.unique(names(conf_list))
+
+  structure(conf_list, class = c("Confusion", "listof"))
+}
+
+
+ConfusionMatrix <- function(object) {
+   structure(object, class = c("ConfusionMatrix", "table"))
+}
+
+
+HTestPerformanceDiff <- setClass("HTestPerformanceDiff",
+  slots = c("adjust" = "character"),
+  contains = "array"
+)
+
+
+#' @name lift
+#' @rdname lift
+#' 
+#' @param ... named or unnamed \code{lift} output to combine together with the
+#' \code{Lift} constructor.
+#' 
+Lift <- function(...) {
+  args <- list(...)
+  
+  if (!all(sapply(args, is.data.frame))) {
+    stop("values to combine must inherit from data.frame")
+  }
+  
+  var_names <- c("Found", "Tested")
+  for (x in args) {
+    is_missing <- !(var_names %in% names(x))
+    if (any(is_missing)) {
+      stop("missing lift variables: ", toString(var_names[is_missing]))
+    }
+  }
+
+  args <- make_unique_levels(args, which = "Model")
+  new("Lift", do.call(append, args))
+}
+
+
+setClass("Lift",
+  contains = "data.frame"
+)
+
+
+PartialDependence <- function(object) {
+  structure(object, class = c("PartialDependence", "data.frame"))
+}
+
+
+Performance <- function(...) {
+  args <- list(...)
+  
+  perf <- if (length(args) > 1) {
+    abind(args, along = 3)
+  } else {
+    args[[1]]
+  }
+  
+  new("Performance", perf)
+}
+
+
+setClass("Performance",
+  contains = "array"
+)
+
+
+PerformanceDiff <- setClass("PerformanceDiff",
+  slots = c("model_names" = "character"),
+  contains = "Performance"
+)
+
+
+MLModelTune <- setClass("MLModelTune",
+  slots = c(grid = "data.frame",
+            performance = "Performance",
+            selected = "numeric"),
+  contains = "MLModel"
+)
+
+
 #' @name resample
 #' @rdname resample-methods
 #' 
@@ -304,130 +548,6 @@ setClass("Resamples",
 )
 
 
-MLModelTune <- setClass("MLModelTune",
-  slots = c(grid = "data.frame", resamples = "Resamples", selected = "numeric"),
-  contains = "MLModel"
-)
-
-
-#' @name calibration
-#' @rdname calibration
-#' 
-#' @param ... named or unnamed \code{calibration} output to combine together
-#' with the \code{Calibration} constructor.
-#' 
-Calibration <- function(...) {
-  args <- list(...)
-  
-  if (!all(sapply(args, is.data.frame))) {
-    stop("values to combine must inherit from data.frame")
-  }
-  
-  var_names <- c("Response", "Midpoint", "Observed")
-  for (x in args) {
-    is_missing <- !(var_names %in% names(x))
-    if (any(is_missing)) {
-      stop("missing calibration variables: ", toString(var_names[is_missing]))
-    }
-  }
-
-  args <- make_unique_levels(args, which = "Model")
-  new("Calibration", do.call(append, args))
-}
-
-
-setClass("Calibration",
-  contains = "data.frame"
-)
-
-
-#' @name confusion
-#' @rdname confusion
-#' 
-#' @param ... named or unnamed \code{confusion} output to combine together with
-#' the \code{Confusion} constructor.
-#' 
-Confusion <- function(...) {
-  args <- list(...)
-  
-  conf_list <- list()
-  for (i in seq(args)) {
-    x <- args[[i]]
-    if (is(x, "ConfusionMatrix")) {
-      x <- list("Model" = x)
-    } else if (!is(x, "Confusion")) {
-      stop("values to combine must be Confusion or ConfusionMatrix objects")
-    }
-    arg_name <- names(args)[i]
-    if (!is.null(arg_name) && nzchar(arg_name)) {
-      names(x) <- rep(arg_name, length(x))
-    }
-    conf_list <- c(conf_list, x)
-  }
-  names(conf_list) <- make.unique(names(conf_list))
-
-  structure(conf_list, class = c("Confusion", "listof"))
-}
-
-
-ConfusionMatrix <- function(object) {
-   structure(object, class = c("ConfusionMatrix", "table"))
-}
-
-
-HTestResamples <- setClass("HTestResamples",
-  slots = c("adjust" = "character"),
-  contains = "array"
-)
-
-
-#' @name lift
-#' @rdname lift
-#' 
-#' @param ... named or unnamed \code{lift} output to combine together with the
-#' \code{Lift} constructor.
-#' 
-Lift <- function(...) {
-  args <- list(...)
-  
-  if (!all(sapply(args, is.data.frame))) {
-    stop("values to combine must inherit from data.frame")
-  }
-  
-  var_names <- c("Found", "Tested")
-  for (x in args) {
-    is_missing <- !(var_names %in% names(x))
-    if (any(is_missing)) {
-      stop("missing lift variables: ", toString(var_names[is_missing]))
-    }
-  }
-
-  args <- make_unique_levels(args, which = "Model")
-  new("Lift", do.call(append, args))
-}
-
-
-setClass("Lift",
-  contains = "data.frame"
-)
-
-
-ModelMetrics <- setClass("ModelMetrics",
-  contains = "array"
-)
-
-
-ModelMetricsDiff <- setClass("ModelMetricsDiff",
-  slots = c("model_names" = "character"),
-  contains = "ModelMetrics"
-)
-
-
-PartialDependence <- function(object) {
-  structure(object, class = c("PartialDependence", "data.frame"))
-}
-
-
 SummaryConfusion <- setClass("SummaryConfusion",
   slots = c("N" = "numeric", "Accuracy" = "numeric", "Majority" = "numeric",
             "Kappa" = "numeric"),
