@@ -68,12 +68,12 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
 
   MLModel(
     name = "BlackBoostModel",
+    label = "Gradient Boosting with Regression Trees",
     packages = c("mboost", "partykit"),
     types = c("binary", "numeric", "Surv"),
     params = params,
     nvars = function(data) nvars(data, design = "terms"),
     fit = function(formula, data, weights, family = NULL, ...) {
-      environment(formula) <- environment()
       if (is.null(family)) {
         family <- switch_class(response(formula, data),
                                "factor" = mboost::Binomial(),
