@@ -48,6 +48,7 @@ EarthModel <- function(pmethod = c("backward", "none", "exhaustive", "forward",
   
   MLModel(
     name = "EarthModel",
+    label = "Multivariate Adaptive Regression Splines",
     packages = "earth",
     types = c("factor", "numeric"),
     params = params(environment()),
@@ -56,8 +57,7 @@ EarthModel <- function(pmethod = c("backward", "none", "exhaustive", "forward",
       attachment(list(
         contr.earth.response = earth::contr.earth.response
       ), name = "earth_exports")
-
-      environment(formula) <- environment()
+      
       family <- switch_class(response(formula, data),
                              "factor" = "binomial",
                              "numeric" = "gaussian")
