@@ -36,12 +36,12 @@ GBMModel <- function(distribution = NULL, n.trees = 100,
   
   MLModel(
     name = "GBMModel",
+    label = "Generalized Boosted Regression",
     packages = "gbm",
     types = c("factor", "numeric", "Surv"),
     params = params(environment()),
     nvars = function(data) nvars(data, design = "terms"),
     fit = function(formula, data, weights, distribution = NULL, ...) {
-      environment(formula) <- environment()
       if (is.null(distribution)) {
         distribution <- switch_class(response(formula, data),
                                      "factor" = "multinomial",
