@@ -50,13 +50,13 @@ MDAModel <- function(subclasses = 3, sub.df = NULL, tot.df = NULL,
   
   MLModel(
     name = "MDAModel",
+    label = "Mixture Discriminant Analysis",
     packages = "mda",
     types = "factor",
     params = params(environment()),
     nvars = function(data) nvars(data, design = "model.matrix"),
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
-      environment(formula) <- environment()
       mda::mda(formula, data = data, ...)
     },
     predict = function(object, newdata, prior = object$prior, ...) {
