@@ -45,12 +45,12 @@ NNetModel <- function(size = 1, linout = FALSE, entropy = NULL, softmax = NULL,
   
   MLModel(
     name = "NNetModel",
+    label = "Feed-Forward Neural Networks",
     packages = "nnet",
     types = c("factor", "numeric"),
     params = params(environment()),
     nvars = function(data) nvars(data, design = "model.matrix"),
     fit = function(formula, data, weights, ...) {
-      environment(formula) <- environment()
       nnet::nnet(formula, data = data, weights = weights, ...)
     },
     predict = function(object, newdata, ...) {
