@@ -27,13 +27,13 @@ PLSModel <- function(ncomp = 1, scale = FALSE) {
   
   MLModel(
     name = "PLSModel",
+    label = "Partial Least Squares",
     packages = "pls",
     types = c("factor", "numeric"),
     params = params(environment()),
     nvars = function(data) nvars(data, design = "model.matrix"),
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
-      environment(formula) <- environment()
       y <- response(formula, data)
       if (is.factor(y)) {
         varname <- response(terms(formula))
