@@ -37,13 +37,13 @@ RandomForestModel <- function(ntree = 500,
   
   MLModel(
     name = "RandomForestModel",
+    label = "Random Forests",
     packages = "randomForest",
     types = c("factor", "numeric"),
     params = params(environment()),
     nvars = function(data) nvars(data, design = "terms"),
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
-      environment(formula) <- environment()
       randomForest::randomForest(formula, data = data, ...)
     },
     predict = function(object, newdata, fitbits, ...) {
