@@ -31,12 +31,12 @@ TreeModel <- function(mincut = 5, minsize = 10, mindev = 0.01,
   
   MLModel(
     name = "TreeModel",
+    label = "Regression and Classification Trees",
     packages = "tree",
     types = c("factor", "numeric"),
     params = params(environment()),
     nvars = function(data) nvars(data, design = "terms"),
     fit = function(formula, data, weights, split, ...) {
-      environment(formula) <- environment()
       tree::tree(formula, data = data, weights = weights, split = split, ...)
     },
     predict = function(object, newdata, times, ...) {
