@@ -1,8 +1,8 @@
 #' Model Tuning and Selection
 #' 
 #' Evaluate a model over a grid of tuning parameters or a list of specified
-#' model objects and select the best one according to resample estimation of
-#' predictive performance.
+#' models and select the best one according to resample estimation of predictive
+#' performance.
 #' 
 #' @name tune
 #' @rdname tune-methods
@@ -22,8 +22,8 @@ tune <- function(x, ...) {
 #' @rdname tune-methods
 #' 
 #' @param data \code{data.frame} containing observed predictors and outcomes.
-#' @param models \code{MLModel} constructor function or character string or a
-#' list of \code{MLModel} contructors or objects.
+#' @param models \code{MLModel} function, function name, object or list of the
+#' aforementioned elements such as that returned by \code{\link{expand.model}}.
 #' @param grid \code{data.frame} containing parameter values over which to
 #' evaluate \code{models} when a single constructor is specified.  Ignored in
 #' the case of a list of models.
@@ -32,16 +32,18 @@ tune <- function(x, ...) {
 #' employed.
 #' @param metrics function, one or more function names, or list of named
 #' functions to include in the calculation of performance metrics.  The default
-#' \code{\link{modelmetrics}} are used unless otherwise specified.  Model
+#' \code{\link{performance}} metrics are used unless otherwise specified.  Model
 #' selection is based on the first specified metric.
 #' @param stat function to compute a summary statistic on resampled values of
 #' the metric for model selection.
 #' @param maximize logical indicating whether to select the model having the
-#' maximum or minimum value of the performance metric.
+#' maximum or minimum value of the performance metric.  Set automatically if a
+#' package \code{\link{metrics}} function is explicitly specified for the model
+#' selection.
 #' 
 #' @seealso \code{\link{ModelFrame}}, \code{\link[recipes]{recipe}},
-#' \code{\link{modelinfo}}, \code{\link{MLControl}}, \code{\link{fit}},
-#' \code{\link{plot}}, \code{\link{summary}}
+#' \code{\link{modelinfo}}, \code{\link{expand.model}}, \code{\link{MLControl}},
+#' \code{\link{fit}}, \code{\link{plot}}, \code{\link{summary}}
 #' 
 #' @examples
 #' \donttest{
@@ -87,36 +89,47 @@ tune.recipe <- function(x, models, grid = data.frame(),
 }
 
 
-.tune <- function(x, data, models, grid, control, metrics, stat, maximize,
-                  ...) {
+.tune <-
+  function(x, data, models, grid, control, metrics, stat, maximize, ...) {
   
   if (is.list(models)) {
-    models <- lapply(models, getMLObject, class = "MLModel")
+    model_names <- character()
+    for (i in seq(models)) {
+      models[[i]] <- getMLObject(models[[i]], class = "MLModel")
+      name <- names(models)[i]
+      model_names[i] <- 
+        if (!is.null(name) && nzchar(name)) name else models[[i]]@name
+    }
+    names(models) <- make.unique(model_names)
     grid <- data.frame()
   } else {
-    models <- split(grid, seq(max(1, nrow(grid)))) %>%
-      lapply(function(params) do.call(models, params))
+    model <- getMLObject(models, class = "MLModel")
+    models <- expand.model(list(get(model@name, mode = "function"), grid))
   }
   
   control <- getMLObject(control, "MLControl")
   
-  modelmetrics_tune <-
+  performance_tune <-
     ifelse(is.null(metrics),
-           function(x) modelmetrics(x, ...),
-           function(x) modelmetrics(x, metrics = metrics, ...))
+           function(x) performance(x, ...),
+           function(x) performance(x, metrics = metrics, ...))
 
-  resamples <- list()
-  perf <- numeric()
-  for (i in seq(models)) {
-    resamples[[i]] <- resample(x, data = data, model = models[[i]],
-                               control = control)
-    modmets <- modelmetrics_tune(resamples[[i]])
-    perf[i] <- stat(na.omit(modmets[, 1]))
+  perf_list <- list()
+  perf_stat <- numeric()
+  for (name in names(models)) {
+    res <- resample(x, data = data, model = models[[name]], control = control)
+    perf_list[[name]] <- performance_tune(res)
+    perf_stat[name] <- stat(na.omit(perf_list[[name]][, 1]))
   }
-  selected <- ifelse(maximize, which.max, which.min)(perf)
+  perf <- do.call(Performance, perf_list)
   
-  MLModelTune(models[[selected]], grid = grid,
-              resamples = do.call(Resamples, resamples),
-              selected = structure(selected, names = colnames(modmets)[1]))
+  metric <- metrics
+  if (is(metric, "vector")) metric <- metric[[1]]
+  if (is(metric, "character")) metric <- get(metric, mode = "function")
+  if (is(metric, "MLMetric")) maximize <- metric@maximize
+  selected <- ifelse(maximize, which.max, which.min)(perf_stat)
+  
+  MLModelTune(models[[selected]], grid = grid, performance = perf,
+              selected = structure(selected, names = colnames(perf)[1]))
   
 }
